diff -aur a/package.c b/package.c
--- a/package.c	2013-04-22 21:36:16.000000000 +1000
+++ b/package.c	2013-05-28 12:34:14.000000000 +1000
@@ -141,19 +141,19 @@
 	}
 
 	cols = getcols(fileno(stdout));
+	const colstr_t *colstr = &config->colstr;
 
 	/* actual output */
 	if(from == ALPM_PKG_FROM_SYNCDB) {
-		string_display(_("Repository     :"),
-				alpm_db_get_name(alpm_pkg_get_db(pkg)), cols);
+		string_display(_("Repository     :"), string_colour(alpm_db_get_name(alpm_pkg_get_db(pkg)), colstr->repo), cols);
 	}
-	string_display(_("Name           :"), alpm_pkg_get_name(pkg), cols);
-	string_display(_("Version        :"), alpm_pkg_get_version(pkg), cols);
-	string_display(_("Description    :"), alpm_pkg_get_desc(pkg), cols);
+	string_display(_("Name           :"), string_colour(alpm_pkg_get_name(pkg), colstr->title), cols);
+	string_display(_("Version        :"), string_colour(alpm_pkg_get_version(pkg), colstr->version), cols);
+	string_display(_("Description    :"), string_colour(alpm_pkg_get_desc(pkg), colstr->warn), cols);
 	string_display(_("Architecture   :"), alpm_pkg_get_arch(pkg), cols);
-	string_display(_("URL            :"), alpm_pkg_get_url(pkg), cols);
+	string_display(_("URL            :"), string_colour(alpm_pkg_get_url(pkg), colstr->meta), cols);
 	list_display(_("Licenses       :"), alpm_pkg_get_licenses(pkg), cols);
-	list_display(_("Groups         :"), alpm_pkg_get_groups(pkg), cols);
+	list_display(_("Groups         :"), list_colour(alpm_pkg_get_groups(pkg), colstr->groups), cols);
 	deplist_display(_("Provides       :"), alpm_pkg_get_provides(pkg), cols);
 	deplist_display(_("Depends On     :"), alpm_pkg_get_depends(pkg), cols);
 	optdeplist_display(pkg, cols);
diff -aur a/util.c b/util.c
--- a/util.c	2013-05-07 13:02:27.000000000 +1000
+++ b/util.c	2013-05-28 12:43:56.000000000 +1000
@@ -424,6 +424,19 @@
 	return len;
 }
 
+/** Colourise a string for improved readability.
+ * @param text the string to be colourised
+ * @param colour the desired colour of the text
+ */
+char *string_colour(const char *text, const char *colour)
+{
+	char *clrd_txt = NULL;
+
+	pm_asprintf(&clrd_txt, "%s%s", colour, text);
+
+	return clrd_txt;
+}
+
 void string_display(const char *title, const char *string, unsigned short cols)
 {
 	if(title) {
@@ -612,6 +625,29 @@
 	return 0;
 }
 
+/** Colourise a list for improved readability.
+ * @param list the strings to be colourised
+ * @param colour the desired colour of the text
+ */
+alpm_list_t *list_colour(const alpm_list_t *list, const char *colour)
+{
+	char *clrd_txt = NULL;
+	const char *text = list->data;
+	const alpm_list_t *i;
+	alpm_list_t *clrd_list = NULL;
+
+	pm_asprintf(&clrd_txt, "%s%s", colour, text);
+	clrd_list = alpm_list_add(clrd_list, clrd_txt);
+
+	for(i = alpm_list_next(list); i; i = alpm_list_next(i)) {
+		text = i->data;
+		pm_asprintf(&clrd_txt, "%s%s", colour, text);
+		clrd_list = alpm_list_add(clrd_list, clrd_txt);
+	}
+
+	return clrd_list;
+}
+
 void list_display(const char *title, const alpm_list_t *list,
 		unsigned short maxcols)
 {
diff -aur a/util.h b/util.h
--- a/util.h	2013-04-22 21:36:16.000000000 +1000
+++ b/util.h	2013-05-28 12:36:09.000000000 +1000
@@ -55,9 +55,11 @@
 size_t strtrim(char *str);
 char *strreplace(const char *str, const char *needle, const char *replace);
 alpm_list_t *strsplit(const char *str, const char splitchar);
+char *string_colour(const char *text, const char *colour);
 void string_display(const char *title, const char *string, unsigned short cols);
 double humanize_size(off_t bytes, const char target_unit, int precision,
 		const char **label);
+alpm_list_t *list_colour(const alpm_list_t *list, const char *colour);
 void list_display(const char *title, const alpm_list_t *list,
 		unsigned short maxcols);
 void list_display_linebreak(const char *title, const alpm_list_t *list,
